#ifndef NT2_INCLUDE_FUNCTIONS_NORMINV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NORMINV_HPP_INCLUDED

#include <nt2/statistics/include/functions/norminv.hpp>

#endif
